# Andesite.py
[![CircleCI](https://circleci.com/gh/gieseladev/andesite.py.svg?style=svg)](https://circleci.com/gh/gieseladev/andesite.py)
[![GitHub release](https://img.shields.io/github/release/gieseladev/andesite.py.svg)](https://github.com/gieseladev/andesite.py/releases/latest)
[![PyPI](https://img.shields.io/pypi/v/andesite.py.svg)](https://pypi.org/project/andesite.py)

A Python client library for [Andesite](https://github.com/natanbc/andesite-node).

> Why should you use Andesite instead of something like, say, Lavalink?
> Well, one of the biggest, if not the biggest reason to use Andesite is if
> you don't like reading. Lavalink's docs certainly aren't the best, but Andesite's
> are practically non-existent so you can just YOLO through it instead of
> having to properly implement the details. Isn't that great?

## Documentation
You can find the documentation on the project's website.
[Click here](https://gieseladev.github.io/andesite.py/docs) to open the
documentation.

You can also take a look at the [examples](examples) directory
for a reference.